# ClearIO
Utility library for accessing IO providers in a uniform way.


This library uses the following packages:
- [smbprotocol](https://github.com/jborean93/smbprotocol)
- [pywin32](https://github.com/mhammond/pywin32)
- [Paramiko](https://www.paramiko.org/)

For tests, the following packages are used:
- [python-dotenv](https://github.com/theskumar/python-dotenv)
